CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_params.h File Reference

CCL

Data Structures | Typedefs | Variables
ccl_params.h File Reference

Go to the source code of this file.

## Data Structures
struct | ccl_spline_params

## Typedefs
typedef struct ccl_spline_params | ccl_spline_params

## Variables
ccl_spline_params * | ccl_splines

## Typedef Documentation

## ◆ ccl_spline_params

typedef struct ccl_spline_params ccl_spline_params

Struct that contains all the parameters needed to create certain splines. This includes splines for the scale factor, masses, and power spectra.

## Variable Documentation

## ◆ ccl_splines

ccl_spline_params* ccl_splines